@@ -14,6 +14,7 @@ This database class will handle all access to the hdf5 databses
 import numpy as np
 import time
 import h5py
+from pathlib import Path
 from os.path import join, isfile, isdir
 
 ######## Database Class ########
@@ -124,6 +125,15 @@ class Database(object):
                 #If the resource is busy, try again!
                 time.sleep(np.random.random()*self.sleep)
 
+    def size_on_disk(
+                     self,
+                     group="/",
+                    ):
+        '''
+        Return the size on disk of the database
+        '''
+        return Path(self.fname).stat().st_size
+                        
 
     def change_group(
                      self,
@@ -185,7 +195,6 @@ class Database(object):
             item = Head[parcel]
             # If the group or dataset is not in origin, copy it
             if not (item.name in Origin):
-                print("found it!")
                 Head.copy(item.name, Origin[item.parent.name])
             # If the group or dataset has attributes, copy them
             attrs = dict(item.attrs)
@@ -201,6 +210,26 @@ class Database(object):
             Origin.close()
             Head.close()
 
+    def rebase(self, fname_alias, compression="gzip"):
+        '''\
+        Rebase the database to fee disk space
+        '''
+        import sys
+        import os
+        from os.path import isfile
+        # Check that there's not the alias file already
+        assert not isfile(fname_alias)
+
+        # Create alias database
+        db_alias = Database(fname_alias)
+        # use merge to do the dirty work
+        db_alias.merge(self.fname)
+
+        # overwrite file
+        cmd = "mv %s %s"%(fname_alias, self.fname)
+        print(cmd,file=sys.stderr)
+        os.system(cmd)
+
     def shard(self, fname_head, names = None, compression = "default"):
         '''\
         Create a smaller database with less data
@@ -223,12 +252,12 @@ class Database(object):
             try:
                 with h5py.File(self.fname, 'r') as Origin:
                     # and new database (head)
-                    with h5py.File(fname_head, 'w') as Head:
+                    with h5py.File(fname_head, 'a') as Head:
                         load = True
                         # If names is not given, assume all data is to be copied
                         if names is None:
                             names = self.list_items(kind = "dset")
-                        print("creating shard with members: ", names)
+                        #print("creating shard at %s with members: "%(self.group), names)
 
 
                         # Make sure the group exists in the new dataset
@@ -265,7 +294,6 @@ class Database(object):
                 #If the resource is busy, try again!
                 time.sleep(np.random.random()*self.sleep)
 
-            print("Shard successful!")
 
     def list_items(self, path="./", kind = None):
         '''\
